@@ -1,4 +1,4 @@
-/* Copyright (C) 2005, 2009 Free Software Foundation, Inc.
+/* Copyright (C) 2005-2018 Free Software Foundation, Inc.
 This file is part of the GNU C Library.
 
 The GNU C Library is free software; you can redistribute it and/or
@@ -12,7 +12,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>.  */
+along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -20,10 +20,6 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.  */
 
 #include <math.h>
 
-#ifdef NEED_DECLARATION_HYPOT
-  double hypot(double, double);
-#endif /* NEED_DECLARATION_HYPOT */
-  
 double groff_hypot(double x, double y)
 {
   double result = hypot(x, y);
